powered by
A user friendly wrapper to easily install R packages and Shiny applications developed by Certara
install_certara_packages( CRAN_repo = "https://cloud.r-project.org", clean_install = FALSE, quiet = FALSE )
TRUE if all packages successfully install
TRUE
Character; The URL of a CRAN mirror which defaults to "https://cloud.r-project.org"
"https://cloud.r-project.org"
Logical; Set to TRUE to remove all existing Certara packages prior to installing
Logical; Set to TRUE to suppress installation messages and reduce console output
if (FALSE) { install_certara_packages() }
Run the code above in your browser using DataLab